Module: ActiveRecord
- Defined in:
- lib/onceler/extensions/active_record.rb
Overview
monkey-patch this to not clear connections so that we don't lose our transactions
Defined Under Namespace
Modules: TestFixtures
monkey-patch this to not clear connections so that we don't lose our transactions
Modules: TestFixtures